Learn R Programming

NHPoisson (version 3.4)

unifres.fun: Calculate exponential and uniform (generalized) residuals of a HPP

Description

This function calculates the exponential \(d_i\) and the uniform (generalized) residuals \(u_i\) of a HPP, using the occurrence points \(t_i\).

Usage

unifres.fun(posEH)

Value

A list with elements

expres

Numeric vector of the exponential residuals.

unires

Numeric vector of the uniform residuals.

posEH

Input argument.

Arguments

posEH

Numeric vector, the occurrence points of a HPP.

Details

The exponential residuals of a HPP are defined as the inter-event distances \(d_i=t_i-t_{i-1}\), that are an i.i.d. exponential sample. The series \(d_i\) is an example of the generalized residuals proposed by Cox and Snell (1968). The uniform residuals, defined as the function \(\exp(-d_i)\) of the exponential residuals, are an i.i.d. uniform sample, see Ogata (1988).

References

Abaurrea, J., Asin, J., Cebrian, A.C. and Centelles, A. (2007). Modeling and forecasting extreme heat events in the central Ebro valley, a continental-Mediterranean area. Global and Planetary Change, 57(1-2), 43-58.

Cebrian, A.C., Abaurrea, J. and Asin, J. (2015). NHPoisson: An R Package for Fitting and Validating Nonhomogeneous Poisson Processes. Journal of Statistical Software, 64(6), 1-24.

Cox, D. R. and Snell, E. J. (1968). A general definition of residuals. Journal of the Royal Statistical Society, series B, 30(2), 248-275. 83(401), 9-27.

Ogata, Y. (1988). Statistical models for earthquake occurrences and residual analysis for point processes.Journal of the American Statistical Association, 83(401), 9-27.

See Also

transfH.fun, graphresU.fun

Examples

Run this code
## generates the occurrence times of a homogeneours PP with  constant intensity 0.01 
## and calculates de residuals

aux<-simNHP.fun(lambda=rep(0.01,1000))

res<-unifres.fun(aux$posNH)

Run the code above in your browser using DataLab